@@ -13,7 +13,10 @@ impl FileComponent {
     pub fn new(log_file_name: &str) -> Self {
         if !Path::new("./log/").exists() {
             if let Err(error) = create_dir(Path::new("./log/")) {
-                panic!("Failed to create directory for logger files output with error: {}", error);
+                panic!(
+                    "Failed to create directory for logger files output with error: {}",
+                    error
+                );
             }
         }
 
