@@ -1,8 +1,8 @@
 use super::component::LoggerComponent;
 use super::message::Message;
-use std::cell::{RefCell};
+use std::cell::RefCell;
 use std::collections::LinkedList;
-use std::io::{Error, ErrorKind};
+use std::io::Error;
 use std::rc::Rc;
 
 pub struct Logger {
