@@ -1,17 +1,17 @@
-use chrono::{Local};
+use chrono::Local;
 
 pub enum MessageType {
     CLIENT,
     DEBUG,
-    ENGINE
+    ENGINE,
 }
 
 impl ToString for MessageType {
     fn to_string(&self) -> String {
         match self {
-            MessageType::CLIENT => {String::from("CLIENT: ")}
-            MessageType::DEBUG => {String::from("DEBUG: ")}
-            MessageType::ENGINE => {String::from("ENGINE: ")}
+            MessageType::CLIENT => String::from("CLIENT: "),
+            MessageType::DEBUG => String::from("DEBUG: "),
+            MessageType::ENGINE => String::from("ENGINE: "),
         }
     }
 }
@@ -19,15 +19,15 @@ impl ToString for MessageType {
 pub enum MessageSeverity {
     TRACE,
     WARN,
-    ERROR(String) // MessageTypeData is the debug string from the error produced
+    ERROR(String), // MessageTypeData is the debug string from the error produced
 }
 
 impl ToString for MessageSeverity {
     fn to_string(&self) -> String {
         match self {
-            MessageSeverity::TRACE => {String::from("TRACE: ")}
-            MessageSeverity::WARN => {String::from("WARN: ")}
-            MessageSeverity::ERROR(_) => {String::from("ERROR: ")}
+            MessageSeverity::TRACE => String::from("TRACE: "),
+            MessageSeverity::WARN => String::from("WARN: "),
+            MessageSeverity::ERROR(_) => String::from("ERROR: "),
         }
     }
 }
@@ -35,7 +35,7 @@ impl ToString for MessageSeverity {
 pub struct Message {
     mtype: MessageType,
     mseverity: MessageSeverity,
-    mdata: String
+    mdata: String,
 }
 
 impl Message {
@@ -43,7 +43,7 @@ impl Message {
         Self {
             mtype: MessageType::CLIENT,
             mseverity: MessageSeverity::TRACE,
-            mdata: String::from("")
+            mdata: String::from(""),
         }
     }
 
@@ -90,4 +90,4 @@ impl ToString for Message {
 
         sbuilder
     }
-}
\ No newline at end of file
+}
